@@ -76,7 +76,7 @@ protected:
 
 class InterfaceStatistics : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     /**
